#
# spec file for package python-python-keycloak
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global modname python-keycloak
Name:           python-%{modname}
Version:        3.7.0
Release:        1.3
Summary:        Python package providing access to the Keycloak API
License:        MIT
URL:            https://github.com/marcospereirampj/python-keycloak
Source:         https://github.com/marcospereirampj/python-keycloak/archive/refs/tags/v%{version}.tar.gz#/python-keycloak-%{version}.tar.gz
Patch0:         fix-version.patch
BuildRequires:  %{python_module base}
BuildRequires:  %{python_module deprecation}
BuildRequires:  %{python_module freezegun}
BuildRequires:  %{python_module httmock}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-jose}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-deprecation
Requires:       python-python-jose >= 1.4.0
Requires:       python-requests >= 2.20.0
Requires:       python-requests-toolbelt
BuildArch:      noarch
%python_subpackages

%description
Python package providing access to the Keycloak API

%prep
%autosetup -p1 -n %{modname}-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%fdupes %{buildroot}

%check
# Certain parts of the testsuite requiring a running keycloak service. However
# the code is absolutely dependant on these variables being in the environment
. tox.env
export KEYCLOAK_HOST=localhost
export KEYCLOAK_ADMIN KEYCLOAK_ADMIN_PASSWORD KEYCLOAK_PORT
%pytest --ignore tests/test_keycloak_admin.py --ignore tests/test_keycloak_openid.py --ignore tests/test_keycloak_uma.py

%files %{python_files}
%doc README.md
%doc %{python_sitelib}/CHANGELOG.md
%doc %{python_sitelib}/CONTRIBUTING.md
%license %{python_sitelib}/LICENSE
%{python_sitelib}/keycloak
%{python_sitelib}/python_keycloak-%{version}.dist-info

%changelog
* Wed Feb 14 2024 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.7.0:
  * add KeycloakAdmin.get_idp()
  * Update dynamic client using registration access token
  * add an optional search criteria to the get_realm_roles function
  * added KeycloakAdmin.update_client_authz_resource()
  * Implement missing admin method create_client_authz_scope_based_permission()
    and create_client_authz_policy()
  * Add query to get users group method and permit pagination
  * Changes the exchange token API
  * do not swap realm for user_realm when logging in with a client service
    account
  * Fixes `Authorization.load_config` breaking if a scope based permission
    is linked with anything other than a role based policy.
  * Add get and delete methods for client authz resources
  * loose requests pgk and remove urllib3 as dependency
  * Check if _s exists in ConnectionManager before deleting it
  * deprecation warnings in keycloak_admin.py
  * Add UMA policy management and permission tickets
  * add initial access token support and policy delete method
  * Check if applyPolicies exists in the config
  * implement cache clearing API
  * get_group_by_path uses Keycloak API to load
  * add Keycloak UMA client
  * update header if token is given
  * init KeycloakAdmin with token
  * added default realm roles handlers
  * fix testing create_client_authz_scopes parameters
  * option for enabling users
  * helping functions for disabling users
- Add patch fix-version.patch:
  * Set a version in pyproject.toml.
- Switch to github tarball.
* Tue Dec 13 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version v2.6.0 (2022-10-03)
  Feat
  * attack detection API implementation
- Update to v2.5.0 (2022-08-19)
  No changelog
- Update to v2.4.0 (2022-08-19)
  Feat
  * add client scope-mappings client roles operations
  * added missing functionality to include attributes when returning realm roles according to specifications
- Update to v2.3.0 (2022-08-13)
  Feat
  * Add token_type/scope to token exchange api
- Update to v2.2.0 (2022-08-12)
  Feat
  * add client scope-mappings realm roles operations
- Update to v2.1.1 (2022-07-19)
  Fix
  * removed whitespace from urls
  Refactor
  * applied linting
-Update to v2.1.0 (2022-07-18)
  Feat
  * add unit tests
  * add docstrings
  * add functions covering some missing REST API calls
  Fix
  * linting
  * now get_required_action_by_alias now returns None if action does not exist
  * moved imports at the top of the file
  * remove duplicate function
  * applied tox -e docs
  * applied flake linting checks
  * applied tox linting check
-Update to v2.0.0 (2022-07-17)
  BREAKING CHANGE
  * Renamed parameter client_name to client_id in get_client_id method
  Fix
  * check client existence based on clientId
* Sat Apr 30 2022 Matej Cepl <mcepl@suse.com>
- Enable tests
- Clean up the spec file
* Thu Apr 21 2022 Michael Ströder <michael@stroeder.com>
- initial packaging of version 0.27.0
